'use strict';

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var spawn = require('cross-spawn');

var _require = require('../utils'),
    ifScript = _require.ifScript,
    hasScript = _require.hasScript,
    parseEnv = _require.parseEnv,
    resolveBin = _require.resolveBin;

// precommit runs linting and tests on the relevant files
// so those scripts don't need to be run if we're running
// this in the context of a precommit hook.


var ifScriptAndNotPreCommit = function ifScriptAndNotPreCommit(scriptName, script) {
  return !parseEnv('SCRIPTS_PRECOMMIT', false) && hasScript(scriptName) ? script : null;
};

var validateScripts = process.argv[3];

var scriptNames = function scriptNames() {
  for (var _len = arguments.length, scripts = Array(_len), _key = 0; _key < _len; _key++) {
    scripts[_key] = arguments[_key];
  }

  return scripts.map(function (s) {
    return ifScript(s, s);
  }).filter(Boolean).join(',');
};

var useDefaultScripts = typeof validateScripts !== 'string';

var scripts = useDefaultScripts ? [ifScript('build', 'npm run build --silent'), ifScriptAndNotPreCommit('lint', 'npm run lint --silent'), ifScriptAndNotPreCommit('test', 'npm run test --silent -- --coverage')].filter(Boolean) : validateScripts.split(',').map(function (npmScript) {
  return `npm run ${npmScript} -s`;
});
var names = useDefaultScripts ? scriptNames('build', 'lint', 'test') : validateScripts.split(',');

var colors = ['bgBlue.bold', 'bgGreen.bold', 'bgMagenta.bold', 'black.bgWhite.bold', 'white.bgBlack.bold', 'bgRed.bold'].join(',');

var result = spawn.sync(resolveBin('concurrently'),
// prettier-ignore
['--kill-others-on-fail', '--prefix', '[{name}]', '--names', names, '--prefix-colors', colors].concat(_toConsumableArray(scripts)), { stdio: 'inherit' });

process.exit(result.status);